﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using TeeChart;
using System.IO;

namespace XaxisProblem2
{
    class Program
    {
        static void Main(string[] args)
        {
            var tChart = new TChart();
            initial(tChart);

            ISeries iSeries;

            // add first series
            iSeries = tChart.Series(tChart.AddSeries(ESeriesClass.scPoint));
            iSeries.asPoint.Pointer.Style = EPointerStyle.psTriangle;
            iSeries.Color = 0x00ff00;
            for (int i = 0; i < 50; i++)
                iSeries.AddXY(i, 1, "first" + i, 0x00ff00);

            // add second series
            iSeries = tChart.Series(tChart.AddSeries(ESeriesClass.scPoint));
            iSeries.asPoint.Pointer.Style = EPointerStyle.psTriangle;
            iSeries.Color = 0x0000ff;
            for (int i = 0; i < 50; i++)
                iSeries.AddXY(i + 0.5, 2, "second" + i, 0x0000ff);

            var fileName = Path.Combine( Environment.CurrentDirectory,"sample.png");
            tChart.Export.asPNG.SaveToFile(fileName);
        }

        static void initial(TChart tChart)
        {
            tChart.Environment.IEPrintWithPage = true;
            tChart.Frame.Visible = true;

            tChart.Aspect.Orthogonal = false;
            tChart.Aspect.Perspective = 35;
            tChart.Aspect.HorizOffset = -20;
            tChart.Aspect.View3D = false;

            tChart.Walls.Back.Color = 0;
            tChart.Walls.Back.Transparent = false;
            tChart.Walls.Back.Gradient.StartColor = 0;
            tChart.Walls.Back.Gradient.MidColor = 0;
            tChart.Walls.Back.Gradient.EndColor = 0;

            tChart.Legend.Alignment = (ELegendAlignment)3;
            tChart.Legend.TopPos = 0;
            tChart.Legend.Visible = false;

            tChart.Header.Text.Clear();
            tChart.Header.AdjustFrame = true;
            tChart.Header.Alignment = ETitleAlignment.taCenter;
            tChart.Header.Shadow.Visible = false;
            tChart.Header.Transparent = true;

            tChart.Axis.Left.Title.Angle = 90;
            tChart.Axis.Left.Labels.Style = EAxisLabelStyle.talValue;
            tChart.Axis.Left.StartPosition = 2;
            tChart.Axis.Left.EndPosition = 98;
            tChart.Axis.Bottom.Title.Angle = 0;
            tChart.Axis.Bottom.Labels.Style = EAxisLabelStyle.talText;
            tChart.Axis.Bottom.StartPosition = 2;
            tChart.Axis.Bottom.EndPosition = 98;
            tChart.Axis.Bottom.Labels.Angle = 270;
            tChart.Axis.Bottom.Labels.Separation = 10;

            tChart.Panel.Color = 0xFF0000;
            tChart.Panel.BevelWidth = 1;
            tChart.Panel.BevelInner = (EPanelBevel)2;
            tChart.Panel.BevelOuter = (EPanelBevel)1;
            tChart.Panel.Gradient.StartColor = 14544588;
            tChart.Panel.Gradient.MidColor = 14544588;
            tChart.Panel.Gradient.EndColor = 14544588;

            tChart.Footer.Text.Add(0);
            tChart.Footer.Font.Color = 0x0000ff;
            tChart.Footer.Text[0] = "WINBOND";
            tChart.Footer.Alignment = ETitleAlignment.taRightJustify;
        }

    }
}
